@@ -104,6 +104,11 @@ void AsyncClientApiTest::resetModel()
     Nepomuk2::insertOntologies( m_model, graph );
     
     // rebuild the internals of the data management model
+    QDBusInterface(QLatin1String("org.kde.nepomuk.FakeDataManagement"),
+                   QLatin1String("/datamanagement"),
+                   QLatin1String("org.kde.nepomuk.DataManagement"),
+                   QDBusConnection::sessionBus()).call(QLatin1String("clearCache"));
+
     QDBusInterface(QLatin1String("org.kde.nepomuk.FakeDataManagement"),
                    QLatin1String("/fakedms"),
                    QLatin1String("org.kde.nepomuk.FakeDataManagement"),
