@@ -93,14 +93,17 @@ void Nepomuk2::VirtuosoInferenceModel::updateOntologyGraphs(bool forced)
                          Soprano::Query::QueryLanguageUser,
                          QLatin1String("sql"));
 
+            /*
             QString ontGroupQuery = QString::fromLatin1("DB.DBA.RDF_GRAPH_GROUP_INS('%1', '%2')")
                                     .arg( QLatin1String(s_nepomukOntologyGroup),
                                           it[0].uri().toString() );
             executeQuery( ontGroupQuery, Soprano::Query::QueryLanguageUser, QLatin1String("sql"));
             ontologies << it[0].uri();
+            */
         }
 
         // Fetch all the graph metadata graphs
+        /*
         foreach(const QUrl& graphUri, ontologies) {
             QString graphMetaQUery = QString::fromLatin1("select distinct ?r where { ?r %1 %2 . }")
                                     .arg( Soprano::Node::resourceToN3(NRL::coreGraphMetadataFor()),
@@ -119,57 +122,14 @@ void Nepomuk2::VirtuosoInferenceModel::updateOntologyGraphs(bool forced)
                                 .arg( QLatin1String(s_nepomukOntologyGroup),
                                       QLatin1String("http://www.openlinksw.com/schemas/virtrdf#") );
         executeQuery( ontGroupQuery, Soprano::Query::QueryLanguageUser, QLatin1String("sql"));
+        */
     }
 
     m_haveInferenceRule = (ontologyCount > 0);
 
-    // update graph visibility if something has changed or if we never did it
+    // Remove all type visibility stuff
     const QUrl visibilityGraph = QUrl::fromEncoded(s_typeVisibilityGraph);
-    if(forced ||
-       !executeQuery(QString::fromLatin1("ask where { graph %1 { ?s ?p ?o . } }")
-                     .arg(Soprano::Node::resourceToN3(visibilityGraph)),
-                     Soprano::Query::QueryLanguageSparql).boolValue()) {
-        kDebug() << "Need to update type visibility.";
-        updateTypeVisibility();
-    }
-}
-
-void Nepomuk2::VirtuosoInferenceModel::updateTypeVisibility()
-{
-    const QUrl visibilityGraph = QUrl::fromEncoded(s_typeVisibilityGraph);
-
-    // 1. remove all visibility values we added ourselves
-    removeContext(visibilityGraph);
-
-    // 2. Set each type non-visible which has a parent type that is non-visible
-    executeQuery(QString::fromLatin1("insert into %1 { "
-                                     "?t %2 'false'^^%3 . "
-                                     "} where { "
-                                     "?t a rdfs:Class . "
-                                     "filter not exists { ?t %2 ?v . } . "
-                                     "filter exists { ?tt %2 'false'^^%3 .  ?t rdfs:subClassOf ?tt . } }")
-                 .arg(Soprano::Node::resourceToN3(visibilityGraph),
-                      Soprano::Node::resourceToN3(NAO::userVisible()),
-                      Soprano::Node::resourceToN3(XMLSchema::boolean())),
-                 Soprano::Query::QueryLanguageSparql);
-
-    // 3. Set each type visible which is not rdfs:Resource and does not have a non-visible parent
-    executeQuery(QString::fromLatin1("insert into %1 { "
-                                     "?t %2 'true'^^%3 . "
-                                     "} where { "
-                                     "?t a rdfs:Class . "
-                                     "filter not exists { ?t %2 ?v . } . "
-                                     "filter not exists { ?tt %2 'false'^^%3 .  ?t rdfs:subClassOf ?tt . } }")
-                 .arg(Soprano::Node::resourceToN3(visibilityGraph),
-                      Soprano::Node::resourceToN3(NAO::userVisible()),
-                      Soprano::Node::resourceToN3(XMLSchema::boolean())),
-                 Soprano::Query::QueryLanguageSparql);
-
-    // 4. make rdfs:Resource non-visible (this is required since with KDE 4.9 we introduced a new
-    //    way of visibility handling which relies on types alone rather than visibility values on
-    //    resources. Any visible type will make all sub-types visible, too. If rdfs:Resource were
-    //    visible everything would be.
-    removeAllStatements(RDFS::Resource(), NAO::userVisible(), Soprano::Node());
+    removeContext( visibilityGraph );
 }
 
 #include "virtuosoinferencemodel.moc"
